@@ -8,29 +8,39 @@ from .anova import anova
 
 from .cheb import cheb_bld
 from .cheb import cheb_get
-from .cheb import cheb_get_full
+from .cheb import cheb_gets
 from .cheb import cheb_int
 from .cheb import cheb_pol
 from .cheb import cheb_sum
 
 
+from .cheb_full import cheb_bld_full
+from .cheb_full import cheb_get_full
+from .cheb_full import cheb_gets_full
+from .cheb_full import cheb_int_full
+from .cheb_full import cheb_sum_full
+
+
 from .cross import cross
-from .cross import cross_cache2data
 
 
+from .grid import cache_to_data
 from .grid import grid_flat
+from .grid import grid_prep_opt
 from .grid import grid_prep_opts
-from .grid import ind2poi
-from .grid import ind2str
+from .grid import ind_to_poi
 from .grid import sample_lhs
 from .grid import sample_tt
-from .grid import str2ind
 
 
 from .maxvol import maxvol
 from .maxvol import maxvol_rect
 
 
+from .optima import optima_tt
+from .optima import optima_tt_simple
+
+
 from .stat import cdf_confidence
 from .stat import cdf_getter
 
@@ -44,7 +54,6 @@ from .svd import svd_incomplete
 from .tensor import accuracy
 from .tensor import add
 from .tensor import add_many
-from .tensor import const
 from .tensor import copy
 from .tensor import erank
 from .tensor import full
@@ -54,7 +63,6 @@ from .tensor import mean
 from .tensor import mul
 from .tensor import mul_scalar
 from .tensor import norm
-from .tensor import orthogonalize
 from .tensor import rand
 from .tensor import ranks
 from .tensor import shape
@@ -62,4 +70,9 @@ from .tensor import show
 from .tensor import size
 from .tensor import sub
 from .tensor import sum
-from .tensor import truncate
+
+
+from .transformation import orthogonalize
+from .transformation import orthogonalize_left
+from .transformation import orthogonalize_right
+from .transformation import truncate
